@@ -19,8 +19,8 @@
 #ifndef EXPLEXER_H
 #define EXPLEXER_H
 
-#include <QtCore/QString>
-#include <QtCore/QStringList>
+#include <QString>
+#include <QStringList>
 #include "abstractlexer.h"
 #include "analitzaexport.h"
 
@@ -28,7 +28,7 @@ class ANALITZA_EXPORT ExpLexer : public AbstractLexer
 {
     public:
         
-        ExpLexer(const QString &source);
+        explicit ExpLexer(const QString &source);
         
         static QString escape(const QString& str);
         
