@@ -45,12 +45,15 @@ void Graph2DMobile::paint()
         return;
 
 //     qDebug() << "hellooo" << boundingRect();
-    QSize bounding = boundingRect().size().toSize();
+    const auto dpr = window()->effectiveDevicePixelRatio();
+    const QSize bounding = (boundingRect().size() * dpr).toSize();
     if(bounding.isEmpty())
         return;
     
     if(m_buffer.size()!=bounding) {
         m_buffer = QImage(bounding, QImage::Format_ARGB32);
+        m_buffer.setDevicePixelRatio(dpr);
+        setDevicePixelRatio(dpr);
         setPaintedSize(bounding);
     }
     
@@ -99,7 +102,7 @@ void Graph2DMobile::scale(qreal s, int x, int y)
 
 void Graph2DMobile::translate(qreal x, qreal y)
 {
-    moveViewport(QPoint(x,y));
+    moveViewport(QPoint(x,y) * window()->effectiveDevicePixelRatio());
 }
 
 QStringList Graph2DMobile::addFunction(const QString& expression, const QSharedPointer<Analitza::Variables>& vars)
@@ -114,7 +117,7 @@ QStringList Graph2DMobile::addFunction(const QString& expression, const QSharedP
 
 void Graph2DMobile::setTicksShownAtAll(bool shown)
 {
-    Qt::Orientations show = shown ? Qt::Vertical|Qt::Horizontal : Qt::Orientations(0);
+    Qt::Orientations show = shown ? Qt::Vertical|Qt::Horizontal : Qt::Orientations(nullptr);
     setShowTicks(show);
     setShowTickLabels(show);
 }
@@ -135,11 +138,7 @@ QSGNode* Graph2DMobile::updatePaintNode(QSGNode* node, QQuickItem::UpdatePaintNo
     QSGSimpleTextureNode *n = static_cast<QSGSimpleTextureNode *>(node);
     if (!n) {
         n = new QSGSimpleTextureNode();
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 4, 0))
         n->setOwnsTexture(true);
-#else
-#    warning this will leak, you really want to use Qt 5.4
-#endif
     }
     paint();
     n->setTexture(window()->createTextureFromImage(m_buffer));
